FrameData class

Constructors

FrameData({required int frameNumber, required int uiStartMicros, required int uiDurationMicros, required int rasterDurationMicros, required int totalDurationMicros})
const

Properties

frameNumber int
final
hashCode int
The hash code for this object.
no setterinherited
rasterDurationMicros int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalDurationMicros int
final
uiDurationMicros int
final
uiStartMicros int
final
workDurationMicros int
no setter

Methods

isJanky({int targetFps = 60}) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited